@@ -65,6 +65,11 @@
 #endif
 #endif
 
+#ifdef HAVE_RSVG
+#include <librsvg/rsvg.h>
+#include <librsvg/librsvg-features.h>
+#endif
+
 #define EOG_IMAGE_GET_PRIVATE(object) \
 	(G_TYPE_INSTANCE_GET_PRIVATE ((object), EOG_TYPE_IMAGE, EogImagePrivate))
 
@@ -149,6 +154,7 @@ eog_image_free_mem_private (EogImage *image)
 #endif
 
 		priv->status = EOG_IMAGE_STATUS_UNKNOWN;
+		priv->metadata_status = EOG_IMAGE_METADATA_NOT_READ;
 	}
 }
 
@@ -983,7 +989,11 @@ eog_image_real_load (EogImage *img,
 			priv->svg = NULL;
 		}
 
-		if (!strcmp (mime_type, "image/svg+xml")) {
+		if (!strcmp (mime_type, "image/svg+xml")
+#if LIBRSVG_CHECK_FEATURE(SVGZ)
+		    || !strcmp (mime_type, "image/svg+xml-compressed")
+#endif
+		) {
 			gchar *file_path;
 			/* Keep the object for rendering */
 			priv->svg = rsvg_handle_new ();
@@ -1248,17 +1258,17 @@ eog_image_has_data (EogImage *img, EogImageData req_data)
 	priv = img->priv;
 
 	if ((req_data & EOG_IMAGE_DATA_IMAGE) > 0) {
-		req_data = (req_data & !EOG_IMAGE_DATA_IMAGE);
+		req_data = (req_data & ~EOG_IMAGE_DATA_IMAGE);
 		has_data = has_data && (priv->image != NULL);
 	}
 
 	if ((req_data & EOG_IMAGE_DATA_DIMENSION) > 0 ) {
-		req_data = (req_data & !EOG_IMAGE_DATA_DIMENSION);
+		req_data = (req_data & ~EOG_IMAGE_DATA_DIMENSION);
 		has_data = has_data && (priv->width >= 0) && (priv->height >= 0);
 	}
 
 	if ((req_data & EOG_IMAGE_DATA_EXIF) > 0) {
-		req_data = (req_data & !EOG_IMAGE_DATA_EXIF);
+		req_data = (req_data & ~EOG_IMAGE_DATA_EXIF);
 #ifdef HAVE_EXIF
 		has_data = has_data && (priv->exif != NULL);
 #else
@@ -1267,7 +1277,7 @@ eog_image_has_data (EogImage *img, EogImageData req_data)
 	}
 
 	if ((req_data & EOG_IMAGE_DATA_XMP) > 0) {
-		req_data = (req_data & !EOG_IMAGE_DATA_XMP);
+		req_data = (req_data & ~EOG_IMAGE_DATA_XMP);
 #ifdef HAVE_EXEMPI
 		has_data = has_data && (priv->xmp != NULL);
 #endif
